@@ -287,8 +287,20 @@ class CDSLDict:
     # ----------------------------------------------------------------------- #
 
     @lru_cache(maxsize=1)
-    def stats(self):
-        """Display statistics about the lexicon"""
+    def stats(self, top=10):
+        """Display statistics about the lexicon
+
+        Parameters
+        ----------
+        top : int, optional
+            Display top `top` entries having most different meanings.
+            The default is 10.
+
+        Returns
+        -------
+        dict
+            Statistics about the dictionary
+        """
         lex = self._lexicon
         total_count = lex.select().count()
         distinct_query = (
@@ -299,12 +311,24 @@ class CDSLDict:
             .group_by(lex.key)
             .order_by(fn.COUNT(lex.key).desc())
         )
-        top = [(item.key, item.count) for item in distinct_query.limit(10)]
+        top_entries = [
+            (
+                (
+                    transliterate(
+                        item.key,
+                        INTERNAL_SCHEME,
+                        self.output_scheme
+                    ) if self.transliterate_keys else item.key
+                ),
+                item.count
+            )
+            for item in distinct_query.limit(top)
+        ]
         distinct_count = distinct_query.count()
         return {
             "total": total_count,
             "distinct": distinct_count,
-            "top": top
+            "top": top_entries
         }
 
     # ----------------------------------------------------------------------- #
@@ -315,14 +339,16 @@ class CDSLDict:
         pattern,
         input_scheme=None,
         output_scheme=None,
-        ignore_case=False
+        ignore_case=False,
+        limit=None,
+        offset=None
     ):
         """Search in the dictionary
 
         Parameters
         ----------
         pattern : str
-            Search pattern, may contain wildcards.
+            Search pattern, may contain wildcards (`*`).
         input_scheme : str or None, optional
             Input transliteration scheme
             If None, `self.input_scheme` will be used.
@@ -334,6 +360,12 @@ class CDSLDict:
         ignore_case : bool, optional
             Ignore case while performing lookup.
             The default is False.
+        limit : int or None, optional
+            Limit the number of search results to `limit`.
+            The default is None.
+        offset : int or None, optional
+            Offset the search results by `offset`.
+            The default is None
 
         Returns
         -------
@@ -354,7 +386,7 @@ class CDSLDict:
                 scheme=output_scheme,
                 transliterate_keys=self.transliterate_keys
             )
-            for result in search_query
+            for result in search_query.limit(limit).offset(offset)
         ]
 
     def entry(self, entry_id, output_scheme=None):
